<?php
/**
 * Mini-cart
 *
 * Contains the markup for the mini-cart, used by the cart widget.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/mini-cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 9.4.0
 */

defined( 'ABSPATH' ) || exit;

if ( ! isset( $args ) || ! isset( $args['list_class'] ) ) {
    $args['list_class'] = '';
}

$cart_list_sub_class = array();
$cart_list_sub_class[] = 'cart_list_wrap';

if ( ! WC()->cart->is_empty() ) {
    $cart_list_sub_class[] = 'has-cart';
}

?>
<?php do_action( 'woocommerce_before_mini_cart' ); ?>
<div class="<?php echo join( ' ', $cart_list_sub_class ); ?>">
    <div class="cart_list_content">
        <ul class="woocommerce-mini-cart cart_list product_list_widget <?php echo esc_attr( $args['list_class'] ); ?>">
            <?php if ( WC()->cart && ! WC()->cart->is_empty() ) : ?>

                <?php
                do_action( 'woocommerce_before_mini_cart_contents' );

                foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                    $_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                    $product_id   = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

                    if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                        /**
                         * This filter is documented in woocommerce/templates/cart/cart.php.
                         *
                         * @since 2.1.0
                         */
                        $product_name      = apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key );
                        $thumbnail         = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );
                        $product_price     = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
                        $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );

                        ?>
                        <li class="woocommerce-mini-cart-item <?php echo esc_attr( apply_filters( 'woocommerce_mini_cart_item_class', 'mini_cart_item', $cart_item, $cart_item_key ) ); ?>">
                            <div class="cart-left">
                                <?php if ( empty( $product_permalink ) ) : ?>
                                    <?php echo do_shortcode( $thumbnail ) . wp_kses_post( $product_name ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
                                <?php else : ?>
                                    <a href="<?php echo esc_url( $product_permalink ); ?>">
                                        <?php echo do_shortcode( $thumbnail ) . wp_kses_post( $product_name ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
                                    </a>
                                <?php endif; ?>
                            </div>
                            <div class="cart-right">
                                <?php if ( empty( $product_permalink ) ) : ?>
                                    <?php echo esc_html($product_name); ?>
                                <?php else : ?>
                                    <a href="<?php echo get_permalink( $product_id ); ?>">
                                        <?php echo esc_html($product_name); ?>
                                    </a>
                                <?php endif; ?>
                                <?php echo wc_get_formatted_cart_item_data( $cart_item ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>

                                <?php echo apply_filters( 'woocommerce_widget_cart_item_quantity', '<span class="quantity">' . sprintf( '%s &times; %s', $cart_item['quantity'], $product_price ) . '</span>', $cart_item, $cart_item_key ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>

                                <?php
                                    echo apply_filters( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                                        'woocommerce_cart_item_remove_link',
                                        sprintf(
                                            '<a href="%s" class="remove remove_from_cart_button" aria-label="%s" data-product_id="%s" data-cart_item_key="%s" data-product_sku="%s" data-success_message="%s">&times;</a>',
                                            esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
                                            /* translators: %s is the product name */
                                            esc_attr( sprintf( __( 'Remove %s from cart', 'printspace' ), wp_strip_all_tags( $product_name ) ) ),
                                            esc_attr( $product_id ),
                                            esc_attr( $cart_item_key ),
                                            esc_attr( $_product->get_sku() ),
                                            /* translators: %s is the product name */
                                            esc_attr( sprintf( __( '&ldquo;%s&rdquo; has been removed from your cart', 'printspace' ), wp_strip_all_tags( $product_name ) ) )
                                        ),
                                        $cart_item_key
                                    );
                                ?>
                            </div>
                        </li>
                    <?php
                    }
                }

                do_action( 'woocommerce_mini_cart_contents' );
                ?>

            <?php else : ?>
                <li class="empty">
                    <h4><?php echo esc_html__( 'Empty cart', 'printspace' ); ?></h4>
                    <p class="woocommerce-mini-cart__empty-message"><?php echo esc_html__( 'No products in the cart.', 'printspace' ); ?></p>
                    <a href="<?php echo esc_url( get_permalink( wc_get_page_id( 'shop' ) ) ); ?>" class="woocommerce-mini-cart__btn haru-button haru-button--bg-primary haru-button--round-normal haru-button--size-medium"><?php echo esc_html__( 'Return to Shop', 'printspace' ); ?></a>
                </li>
            <?php endif; ?>
        </ul><!-- end product list -->
    </div>

    <?php if ( ! WC()->cart->is_empty() ) : ?>
        <div class="cart-total">
            <p class="woocommerce-mini-cart__total total">
                <?php
                /**
                 * Hook: woocommerce_widget_shopping_cart_total.
                 *
                 * @hooked woocommerce_widget_shopping_cart_subtotal - 10
                 */
                do_action( 'woocommerce_widget_shopping_cart_total' );
                ?>
            </p>

            <?php do_action( 'woocommerce_widget_shopping_cart_before_buttons' ); ?>

            <p class="woocommerce-mini-cart__buttons buttons"><?php do_action( 'woocommerce_widget_shopping_cart_buttons' ); ?></p>

            <?php do_action( 'woocommerce_widget_shopping_cart_after_buttons' ); ?>
        </div>
    <?php endif; ?>

    <?php do_action( 'woocommerce_after_mini_cart' ); ?>
</div>